@@ -1,4 +1,3 @@
-""" block """
 from typing import List, Optional, Callable
 
 from simpy import Environment, Resource
@@ -8,7 +7,11 @@ from casymda.blocks.entity import Entity
 
 
 class Block:
-    """ contains simulation-specific behavior of a basic block """
+    """
+    Provides simulation-specific behavior of a basic block.
+    Entities are accepted via the process_entity entry-point, and standard processing steps are executed.
+    Actual processing behavior is to be provided by subclasses, implementing the actual_processing method.
+    """
 
     def __init__(self, env: Environment, name: str, block_capacity=float("inf")):
         self.name = name
@@ -27,7 +30,7 @@ class Block:
         self.env.process(self.late_state_evaluation())
 
     def on_enter(self, entity: Entity):
-        """on_enter"""
+        """called when process_entity starts"""
         for method in self.do_on_enter_list:
             method(entity, None, self)
 
@@ -93,5 +96,5 @@ class Block:
         self.state_manager.evaluate_state_count()
 
     def actual_processing(self, entity: Entity):
-        """to be implemented"""
+        """to be implemented by concrete subclasses"""
         raise NotImplementedError()
